/*
 * @Author: LiZhiWei
 * @Date: 2025-05-14 15:51:28
 * @LastEditors: LiZhiWei
 * @LastEditTime: 2025-05-14 15:59:07
 * @Description:
 */
import { convertPtToPxInContent } from '../utils/style'
export function createDiagramElement (element) {
  const el = document.createElement('div')
  el.style.position = 'absolute'
  el.style.top = element.top + 'px'
  el.style.left = element.left + 'px'
  el.style.width = element.width + 'px'
  el.style.height = element.height + 'px'
  el.style.zIndex = element.order
  // 递归渲染SmartArt节点
  const renderDiagramNode = (node) => {
    const nodeEl = document.createElement('div')
    nodeEl.style.position = 'absolute'
    nodeEl.style.left = node.left + 'px'
    nodeEl.style.top = node.top + 'px'
    nodeEl.style.width = node.width + 'px'
    nodeEl.style.height = node.height + 'px'

    // 设置边框
    if (node.borderWidth > 0) {
      nodeEl.style.border = `${node.borderWidth}px ${node.borderType} ${node.borderColor}`
      if (node.borderStrokeDasharray && node.borderStrokeDasharray !== '0') {
        nodeEl.style.borderStyle = 'dashed'
      }
    }

    // 设置背景填充
    if (node.fill && node.fill.type === 'color') {
      nodeEl.style.backgroundColor = node.fill.value
    }

    // 设置内容
    if (node.content) {
      nodeEl.innerHTML = convertPtToPxInContent(node.content)
    }

    // 设置垂直对齐
    if (node.vAlign === 'mid') {
      nodeEl.style.display = 'flex'
      nodeEl.style.alignItems = 'center'
      nodeEl.style.justifyContent = 'center'
    }

    // 设置翻转
    const transforms = []
    if (node.isFlipV) {
      transforms.push('scaleY(-1)')
    }
    if (node.isFlipH) {
      transforms.push('scaleX(-1)')
    }
    if (transforms.length > 0) {
      nodeEl.style.transform = transforms.join(' ')
    }

    return nodeEl
  }

  // 按照 order 排序元素
  const sortedElements = [...element.elements].sort((a, b) => a.order - b.order)

  // 渲染所有节点
  sortedElements.forEach((node) => {
    const nodeEl = renderDiagramNode(node)
    el.appendChild(nodeEl)
  })

  return el
}
