import { convertPtToPxInContent } from '../utils/style'
export function createTableElement (element) {
  const el = document.createElement('div')
  el.style.position = 'absolute'
  el.style.top = element.top + 'px'
  el.style.left = element.left + 'px'
  el.style.width = element.width + 'px'
  el.style.height = element.height + 'px'
  el.style.zIndex = element.order

  // 创建表格元素
  const table = document.createElement('table')
  table.style.width = element.width + 'px'
  table.style.height = element.height + 'px'
  table.style.borderCollapse = 'collapse'
  table.style.tableLayout = 'fixed'
  // 设置表格边框
  if (element.borders) {
    if (element.borders.all) {
      const border = element.borders.all
      table.style.border = `${border.borderWidth || 1}px ${border.borderType || 'solid'} ${
        border.borderColor || '#000'
      }`
    } else {
      // 分别设置四边边框
      if (element.borders.top) {
        table.style.borderTop = `${element.borders.top.borderWidth || 1}px ${
          element.borders.top.borderType || 'solid'
        } ${element.borders.top.borderColor || '#000'}`
      }
      if (element.borders.bottom) {
        table.style.borderBottom = `${element.borders.bottom.borderWidth || 1}px ${
          element.borders.bottom.borderType || 'solid'
        } ${element.borders.bottom.borderColor || '#000'}`
      }
      if (element.borders.left) {
        table.style.borderLeft = `${element.borders.left.borderWidth || 1}px ${
          element.borders.left.borderType || 'solid'
        } ${element.borders.left.borderColor || '#000'}`
      }
      if (element.borders.right) {
        table.style.borderRight = `${element.borders.right.borderWidth || 1}px ${
          element.borders.right.borderType || 'solid'
        } ${element.borders.right.borderColor || '#000'}`
      }
    }
  }

  // 创建表格内容
  const tbody = document.createElement('tbody')

  // 处理表格数据
  if (element.data && element.data.length > 0) {
    element.data.forEach((rowData, rowIndex) => {
      const tr = document.createElement('tr')

      rowData.forEach((cell, colIndex) => {
        // 跳过被合并的单元格
        if (cell.hMerge) return

        const td = document.createElement('td')

        // 设置单元格内容
        if (cell.text) {
          td.innerHTML = convertPtToPxInContent(cell.text)
        }

        // 设置单元格样式
        td.style.padding = '0px'
        td.style.verticalAlign = 'middle'

        // 设置文本样式
        if (cell.fontColor) td.style.color = cell.fontColor
        if (cell.fontSize) td.style.fontSize = cell.fontSize
        if (cell.fontFamily) td.style.fontFamily = cell.fontFamily
        if (cell.bold) td.style.fontWeight = 'bold'
        if (cell.italic) td.style.fontStyle = 'italic'
        if (cell.underline) td.style.textDecoration = 'underline'
        if (cell.align) td.style.textAlign = cell.align

        // 设置背景色
        if (cell.fillColor) td.style.backgroundColor = cell.fillColor

        // 设置单元格边框
        if (cell.borders) {
          if (cell.borders.all) {
            const border = cell.borders.all
            td.style.border = `${border.borderWidth || 1}px ${border.borderType || 'solid'} ${
              border.borderColor || '#000'
            }`
          } else {
            // 分别设置四边边框
            if (cell.borders.top) {
              td.style.borderTop = `${cell.borders.top.borderWidth || 1}px ${
                cell.borders.top.borderType || 'solid'
              } ${cell.borders.top.borderColor || '#000'}`
            }
            if (cell.borders.bottom) {
              td.style.borderBottom = `${cell.borders.bottom.borderWidth || 1}px ${
                cell.borders.bottom.borderType || 'solid'
              } ${cell.borders.bottom.borderColor || '#000'}`
            }
            if (cell.borders.left) {
              td.style.borderLeft = `${cell.borders.left.borderWidth || 1}px ${
                cell.borders.left.borderType || 'solid'
              } ${cell.borders.left.borderColor || '#000'}`
            }
            if (cell.borders.right) {
              td.style.borderRight = `${cell.borders.right.borderWidth || 1}px ${
                cell.borders.right.borderType || 'solid'
              } ${cell.borders.right.borderColor || '#000'}`
            }
          }
        }
        td.style.width = element.colWidths[colIndex] + 'px'
        // 设置单元格合并
        if (cell.colSpan && cell.colSpan > 1) {
          td.colSpan = cell.colSpan
          td.style.width = element.colWidths[colIndex] * cell.colSpan + 'px'
        }
        if (cell.rowSpan && cell.rowSpan > 1) {
          td.rowSpan = cell.rowSpan
        }

        tr.appendChild(td)
      })
      tr.style.height = element.rowHeights[rowIndex] + 'px'
      tbody.appendChild(tr)
    })
  }

  table.appendChild(tbody)
  el.appendChild(table)

  return el
}
